@@ -1,6 +1,6 @@
 #
 # -*- Perl -*-
-# $Id: oleexcel.pl,v 1.11 2001/01/27 02:51:29 baba Exp $
+# $Id: oleexcel.pl,v 1.11.4.4 2002/03/27 12:54:19 takesako Exp $
 # Copyright (C) 2001 Yoshinori TAKESAKO,
 #               1999 Jun Kurabe ,
 #               1999 Ken-ichi Hirose All rights reserved.
@@ -51,6 +51,7 @@ use strict;
 require 'util.pl';
 require 'gfilter.pl';
 
+use Win32;
 use Win32::OLE qw(in with);
 use Win32::OLE::Const 'Microsoft Excel';
 
@@ -72,9 +73,9 @@ sub status() {
     open (SAVEERR,">&STDERR");
     open (STDERR,">nul");
     my $const;
-    $const = Win32::OLE::Const->Load("Microsoft Excel 9.0 Object Library");
-    $const = Win32::OLE::Const->Load("Microsoft Excel 8.0 Object Library")
-	unless $const;
+    $const = Win32::OLE::Const->Load("Microsoft Excel 10.0 Object Library");
+    $const = Win32::OLE::Const->Load("Microsoft Excel 9.0 Object Library") unless $const;
+    $const = Win32::OLE::Const->Load("Microsoft Excel 8.0 Object Library") unless $const;
     open (STDERR,">&SAVEERR");
     return 'yes' if (defined $const);
     return 'no';
@@ -98,8 +99,8 @@ sub add_magic ($) {
     return;
 }
 
-sub getProperties ($$) {
-    my ($cfile, $fields) = @_;
+sub getProperties ($$$) {
+    my ($cfile, $fields, $weighted_str) = @_;
 
     # See VBA online help using Microsoft Excel in detail.
     # Topic item: 'DocumentProperty Object'.
@@ -110,6 +111,9 @@ sub getProperties ($$) {
     $fields->{'title'} = codeconv::shiftjis_to_eucjp($title)
 	if (defined $title);
 
+    my $weight = $conf::Weight{'html'}->{'title'};
+    $$weighted_str .= "\x7f$weight\x7f$fields->{'title'}\x7f/$weight\x7f\n";
+
     my $author = $cfile->BuiltInDocumentProperties('Last Author')->{Value};
     $author = $cfile->BuiltInDocumentProperties('Author')->{Value}
 	unless (defined $author);
@@ -122,9 +126,26 @@ sub getProperties ($$) {
     # $fields->{'date'} = codeconv::shiftjis_to_eucjp($date)
     #     if (defined $date);
 
+    my $keyword = $cfile->BuiltInDocumentProperties('keywords')->{Value};
+    $keyword = codeconv::shiftjis_to_eucjp($keyword);
+    $weight = $conf::Weight{'metakey'};
+    $$weighted_str .= "\x7f$weight\x7f$keyword\x7f/$weight\x7f\n";
+
     return undef;
 }
 
+sub Win32_FullPath ($) {
+    # c:/hoge/hoge.xls -> c:\hoge\hoge.xls
+    my $file = shift;
+    if ($] ge 5.006) {
+	$file = Win32::GetFullPathName($file);
+    }
+    $file =~ s|/|\\|g;
+    return $file;
+}
+
+my $Count = 0;
+
 sub filter ($$$$$) {
     my ($orig_cfile, $cont, $weighted_str, $headings, $fields) = @_;
     my $cfile = defined $orig_cfile ? $$orig_cfile : '';
@@ -133,15 +154,10 @@ sub filter ($$$$$) {
     util::vprint("Processing excel file ...\n");
 
     # make temporary file name
-    my $tmpfile0 = util::tmpnam('NMZ.xls0');
-    my $tmpfile1 = util::tmpnam('NMZ.xls1');
-    my $tmpfile2 = util::tmpnam('NMZ.xls2');
-
-    # c:/hoge/hoge.xls -> c:\hoge\hoge.xls
-    $fileName =~ s|/|\\|g;
-    $tmpfile0 =~ s|/|\\|g;
-    $tmpfile1 =~ s|/|\\|g;
-    $tmpfile2 =~ s|/|\\|g;
+    my $tmpfile0 = util::tmpnam("NMZ.xls.$Count.0");
+    my $tmpfile1 = util::tmpnam("NMZ.xls.$Count.1");
+    my $tmpfile2 = util::tmpnam("NMZ.xls.$Count.2");
+    $Count++;
 
     # use existing instance if Excel is already running.
     # my $excel;
@@ -160,17 +176,17 @@ sub filter ($$$$$) {
     # Open the excel workbooks.
     # In order to skip password-protected file, send a dummy password.
     my $Book = $excel->Workbooks->Open({
-	'FileName'			=> $fileName,
-	'ReadOnly'			=> 1,
-	'IgnoreReadOnlyRecommended'	=> 1,
-	'Updatelinks'			=> 0,
-	'WriteResPassword'		=> 'dummy password',
-	'Password'			=> 'dummy password'
+	'FileName'                  => &Win32_FullPath($fileName),
+	'ReadOnly'                  => 1,
+	'IgnoreReadOnlyRecommended' => 1,
+	'Updatelinks'               => 0,
+	'WriteResPassword'          => 'dummy password',
+	'Password'                  => 'dummy password'
     });
     return "$fileName: cannot open file\n" unless (defined $Book);
 
     # get some properties
-    getProperties($Book, $fields);
+    getProperties($Book, $fields, $weighted_str);
 
     # FileHandle for temporary file 1,2
     local (*FH1, *FH2);
@@ -185,10 +201,11 @@ sub filter ($$$$$) {
 	my $sheetName = $sheet->Name;
 
 	# SaveAs xlText FileFormat
-	my $ret = $sheet->SaveAs({
-	    FileName		=>	$tmpfile,	# 
-	    FileFormat		=>	xlText,		# 
-	    CreateBackup	=>	0		# False
+	$sheet->Select;
+	my $ret = $excel->ActiveWorkbook->SaveAs({
+	    'FileName'     => &Win32_FullPath($tmpfile),
+	    'FileFormat'   => xlText,  # xlText
+	    'CreateBackup' => 0        # False
 	});
 
 	# print this sheetName
