@@ -1,9 +1,9 @@
 /*
  * 
- * $Id: util.c,v 1.75.4.2 2001/09/02 07:13:37 rug Exp $
+ * $Id: util.c,v 1.75.4.9 2002/07/26 14:28:22 baba Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -102,9 +102,9 @@ decode_uri_sub(char c1, char c2)
  */
 
 unsigned long
-nmz_scan_oct(char *start, int len, int *retlen)
+nmz_scan_oct(const char *start, int len, int *retlen)
 {
-    register char *s = start;
+    register const char *s = start;
     register unsigned long retval = 0;
 
     while (len-- && *s >= '0' && *s <= '7') {
@@ -117,10 +117,10 @@ nmz_scan_oct(char *start, int len, int *retlen)
 }
 
 unsigned long
-nmz_scan_hex(char *start, int len, int *retlen)
+nmz_scan_hex(const char *start, int len, int *retlen)
 {
     static char hexdigit[] = "0123456789abcdef0123456789ABCDEFx";
-    register char *s = start;
+    register const char *s = start;
     register unsigned long retval = 0;
     char *tmp;
 
@@ -267,20 +267,36 @@ void
 nmz_warn_printf(const char *fmt, ...)
 {
     va_list args;
+    FILE *fp;
 
-    fflush(stdout);
+    if (!nmz_is_loggingmode())
+	return;
+    if (nmz_is_output_warn_to_file()) {
+	fp = fopen(NMZ.warnlog, "a+");
+	if (fp == NULL) {
+	    fprintf(stderr, "Can't open %s.\n", NMZ.warnlog);
+	    return;
+	}
+    } else {
+	fp = stderr;
+    }
 
-    fprintf(stderr, "%s: ", PACKAGE);
+    fflush(fp);
+
+    fprintf(fp, "%s: ", PACKAGE);
 
     va_start(args, fmt);
-    vfprintf(stderr, fmt, args);
+    vfprintf(fp, fmt, args);
     va_end(args);
 
     if (fmt[strlen(fmt) - 1] != '\n') {
-	fprintf(stderr, "\n");
+	fprintf(fp, "\n");
     }
 
-    fflush(stderr);
+    fflush(fp);
+
+    if (fp != stderr)
+	fclose(fp);
 }
 
 /* 
@@ -326,10 +342,11 @@ nmz_pathcat(const char *base, char *name)
             break;
         }
     }
-    strcpy(work, base);
-    strcat(work, "/");
-    strcat(work, name);
-    strcpy(name, work);
+    strncpy(work, base, BUFSIZE - 1);
+    work[BUFSIZE - 1] = '\0';
+    strncat(work, "/", BUFSIZE - strlen(work) - 1);
+    strncat(work, name, BUFSIZE - strlen(work) - 1);
+    strncpy(name, work, BUFSIZE - 1);
 }
 
 int 
@@ -533,7 +550,7 @@ nmz_strerror(enum nmz_stat errnum)
 	msg = _("The index is locked for maintenance");
 	break;
     case ERR_OLD_INDEX_FORMAT:
-	msg = _("The index should be old format.");
+	msg = _("Present index is old type. it's unsupported.");
 	break;
     default:
 	msg = _("Unknown error. Report bug!");
