@@ -7,7 +7,7 @@ package conf;  # Don't remove this line!
 #
 # Administrator's email address
 #
-$ADDRESS = 'webmaster@elmo.local';
+$ADDRESS = 'webmaster@namazu.org';
 
 
 #===================================================================
@@ -183,12 +183,12 @@ $KAKASI = "module_kakasi -ieuc -oeuc -w";
 #
 # ChaSen 1.51 or later (simple wakatigaki)
 #
-$CHASEN = "no";
+$CHASEN = "/usr/bin/chasen -j -F '\%m '";
 
 #
 # ChaSen 1.51 or later (with noun words extraction)
 #
-$CHASEN_NOUN = "no";
+$CHASEN_NOUN = "/usr/bin/chasen -j -F '\%m %H\\n'";
 
 #
 # Default Japanese processer: KAKASI or ChaSen.
